==> SystemCron-1.0.5.tar.gz: SystemCron/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'System cron';
$lang['postuninstall'] = 'Thank you for using this module';
$lang['really_uninstall'] = 'Really? Are you sure
you want to unsinstall this fine module?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['moddescription'] = 'Edit cron jobs via cmsms.';

$lang['error'] = 'Error!';
$land['admin_title'] = 'System cron Admin Panel';
$lang['admindescription'] = $lang['moddescription'];
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['postinstall'] = 'Be sure to set "Use system cron" permissions to use this module!';

$lang['msg.username'] = 'Crontab for user <b>%s</b> is:';

$lang['btn.edit'] = 'Edit';
$lang['btn.save'] = 'Save';
$lang['btn.cancel'] = 'Cancel';

$lang['operation.succeed'] = 'Operation succeed';

$lang['changelog'] = '<ul>
<li>Version 1.0.5 - 24 December 2012. Tested with version 1.11.4.</li>
<li>Version 1.0.4 - 24 November 2012. Tested with version 1.11.3.</li>
<li>Version 1.0.3 - 20 October 2012. Tested with version 1.11.2.1.</li>
<li>Version 1.0.2 - 19 September 2012. Tested with version 1.11.2.</li>
<li>Version 1.0.1 - 21 August 2012. Tested with version 1.11.1.</li>
<li>Version 1.0 - 25 June 2012. Initial release.</li>
<li>Version 1.0beta - 26 May 2012. Initial beta release.</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>Access systems cron and offer other modules easy interface to add &quot;real&quot; cron jobs.</p>
<h3>How Do I Use It</h3>
<p>Please read https://github.com/hasanen/SystemCron/wiki</p>
<h3>Support</h3>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2012, Joni Hasanen <a href="mailto:joni@hasanen.net">&lt;joni@hasanen.net&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';
?>

==> SystemCron-1.0.7.tar.gz: SystemCron/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'System cron';
$lang['postuninstall'] = 'Thank you for using this module';
$lang['really_uninstall'] = 'Really? Are you sure
you want to unsinstall this fine module?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['moddescription'] = 'Edit cron jobs via cmsms.';

$lang['error'] = 'Error!';
$land['admin_title'] = 'System cron Admin Panel';
$lang['admindescription'] = $lang['moddescription'];
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['postinstall'] = 'Be sure to set "Use system cron" permissions to use this module!';

$lang['msg.username'] = 'Crontab for user <b>%s</b> is:';

$lang['btn.edit'] = 'Edit';
$lang['btn.save'] = 'Save';
$lang['btn.cancel'] = 'Cancel';

$lang['operation.succeed'] = 'Operation succeed';

$lang['changelog'] = '<ul>
<li>Version 1.0.7 - 20 April 2013. Tested with version 1.11.6.</li>
<li>Version 1.0.6 - 24 March 2013. Tested with version 1.11.5.</li>
<li>Version 1.0.5 - 24 December 2012. Tested with version 1.11.4.</li>
<li>Version 1.0.4 - 24 November 2012. Tested with version 1.11.3.</li>
<li>Version 1.0.3 - 20 October 2012. Tested with version 1.11.2.1.</li>
<li>Version 1.0.2 - 19 September 2012. Tested with version 1.11.2.</li>
<li>Version 1.0.1 - 21 August 2012. Tested with version 1.11.1.</li>
<li>Version 1.0 - 25 June 2012. Initial release.</li>
<li>Version 1.0beta - 26 May 2012. Initial beta release.</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>Access systems cron and offer other modules easy interface to add &quot;real&quot; cron jobs.</p>
<h3>How Do I Use It</h3>
<p>Please read https://github.com/hasanen/SystemCron/wiki</p>
<h3>Support</h3>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2012, Joni Hasanen <a href="mailto:joni@hasanen.net">&lt;joni@hasanen.net&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';
?>
